import {
  AlertDialog,
  AlertDialogAction,
  AlertDialogCancel,
  AlertDialogContent,
  AlertDialogDescription,
  AlertDialogFooter,
  AlertDialogHeader,
  AlertDialogTitle,
  AlertDialogTrigger,
} from '@/components/ui/alert-dialog';
import { useMemo, useRef, useState } from 'react';

type useConfirmOptions = {
  tip?: React.ReactNode;
  title?: string;
  description?: string;
  onOkText?: string;
  onCancelText?: string;
  onOk?: Fn;
  onCancle?: Fn;
  children?: React.ReactNode;
};
type Fn = () => void;
export const useConfirm = (opts?: useConfirmOptions) => {
  const [open, setOpen] = useState(false);
  const onOkRef = useRef<Fn>(null);
  const onCancle = useRef<Fn>(null);
  type ConfirmOptions = {
    onOk?: Fn;
    onCancel?: Fn;
  };
  const confirm = (opts: ConfirmOptions) => {
    setOpen(true);
    opts.onOk && (onOkRef.current = opts.onOk);
    opts.onCancel && (onCancle.current = opts.onCancel);
  };
  const module = useMemo(() => {
    if (!open) return null;
    return (
      <AlertDialog>
        <AlertDialogTrigger>{opts?.tip ?? '提示'}</AlertDialogTrigger>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>{opts?.title ?? '是否确认删除?'}</AlertDialogTitle>
            <AlertDialogDescription>{opts?.description ?? '此操作无法撤销，是否继续。'}</AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel
              onClick={(e) => {
                setOpen(false);
                onCancle.current && onCancle.current();
                e.stopPropagation();
              }}>
              {opts?.onCancelText ?? '取消'}
            </AlertDialogCancel>
            <AlertDialogAction
              onClick={(e) => {
                setOpen(false);
                onOkRef.current && onOkRef.current();
                e.stopPropagation();
              }}>
              {opts?.onOkText ?? '确定'}
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    );
  }, [open]);
  return {
    module,
    open,
    setOpen,
    confirm,
  };
};

export const Confirm = (opts?: useConfirmOptions) => {
  return (
    <AlertDialog>
      {opts?.children && <AlertDialogTrigger asChild>{opts?.children ?? opts?.tip ?? '提示'}</AlertDialogTrigger>}
      {!opts?.children && <AlertDialogTrigger>{opts?.tip ?? '提示'}</AlertDialogTrigger>}
      <AlertDialogContent>
        <AlertDialogHeader>
          <AlertDialogTitle>{opts?.title ?? '是否确认删除?'}</AlertDialogTitle>
          <AlertDialogDescription>{opts?.description ?? '此操作无法撤销，是否继续。'}</AlertDialogDescription>
        </AlertDialogHeader>
        <AlertDialogFooter>
          <AlertDialogCancel
            onClick={(e) => {
              opts?.onCancle?.();
              e.stopPropagation();
            }}>
            {opts?.onCancelText ?? '取消'}
          </AlertDialogCancel>
          <AlertDialogAction
            onClick={(e) => {
              opts?.onOk?.();
              e.stopPropagation();
            }}>
            {opts?.onOkText ?? '确定'}
          </AlertDialogAction>
        </AlertDialogFooter>
      </AlertDialogContent>
    </AlertDialog>
  );
};
